@@ -21,8 +21,8 @@
 import os.path
 
 PACKAGE   = "gnome-menus"
-VERSION   = "2.24.2"
+VERSION   = "2.28.0.1"
 DATADIR   = "/usr/local/share"
 LOCALEDIR = "/usr/local/share/locale"
 
-GLADEDIR = os.path.join (DATADIR, PACKAGE, "glade")
+UI_DIR = os.path.join (DATADIR, PACKAGE, "ui")
